@@ -29,9 +29,8 @@
 #include "libwpd_internal.h"
 #include "WP3Listener.h"
 #include "WP3ResourceFork.h"
-#include "WPXBinaryData.h"
 
-WP3WindowGroup::WP3WindowGroup(WPXInputStream *input, WPXEncryption *encryption) :
+WP3WindowGroup::WP3WindowGroup(librevenge::RVNGInputStream *input, WPXEncryption *encryption) :
 	WP3VariableLengthGroup(),
 	m_figureFlags(0),
 	m_leftColumn(0),
@@ -56,7 +55,7 @@ WP3WindowGroup::~WP3WindowGroup()
 		delete m_caption;
 }
 
-void WP3WindowGroup::_readContents(WPXInputStream *input, WPXEncryption *encryption)
+void WP3WindowGroup::_readContents(librevenge::RVNGInputStream *input, WPXEncryption *encryption)
 {
 	switch (getSubGroup())
 	{
@@ -67,26 +66,26 @@ void WP3WindowGroup::_readContents(WPXInputStream *input, WPXEncryption *encrypt
 	case WP3_WINDOW_GROUP_EQUATION_BOX_FUNCTION:
 	case WP3_WINDOW_GROUP_HTML_IMAGE_BOX_FUNCTION:
 	{
-		input->seek(14, WPX_SEEK_CUR);
+		input->seek(14, librevenge::RVNG_SEEK_CUR);
 		m_figureFlags = readU16(input, encryption, true); // picture flags
-		input->seek(2, WPX_SEEK_CUR);
+		input->seek(2, librevenge::RVNG_SEEK_CUR);
 		m_leftColumn = readU8(input, encryption); // left align column
 		m_rightColumn = readU8(input, encryption); // right align column
-		input->seek(28, WPX_SEEK_CUR);
+		input->seek(28, librevenge::RVNG_SEEK_CUR);
 		m_boxType = readU8(input, encryption);
-		input->seek(1, WPX_SEEK_CUR);
+		input->seek(1, librevenge::RVNG_SEEK_CUR);
 		m_resourceID = readU16(input, encryption, true);
 		m_verticalOffset = fixedPointToDouble(readU32(input, encryption, true));
 		m_horizontalOffset = fixedPointToDouble(readU32(input, encryption, true));
 		m_width = fixedPointToDouble(readU32(input, encryption, true));
 		m_height = fixedPointToDouble(readU32(input, encryption, true));
-		input->seek(9, WPX_SEEK_CUR);
-		uint8_t tmpNumSubRect = readU8(input, encryption);
-		input->seek(tmpNumSubRect * 8, WPX_SEEK_CUR);
-		uint16_t tmpBoxCaptionSize = readU16(input, encryption, true);
+		input->seek(9, librevenge::RVNG_SEEK_CUR);
+		unsigned char tmpNumSubRect = readU8(input, encryption);
+		input->seek(tmpNumSubRect * 8, librevenge::RVNG_SEEK_CUR);
+		unsigned short tmpBoxCaptionSize = readU16(input, encryption, true);
 		if (tmpBoxCaptionSize)
 			m_caption = new WP3SubDocument(input, encryption, tmpBoxCaptionSize);
-		uint16_t tmpTextBoxLength = readU16(input, encryption, true);
+		unsigned short tmpTextBoxLength = readU16(input, encryption, true);
 		if (tmpTextBoxLength)
 			m_subDocument = new WP3SubDocument(input, encryption, tmpTextBoxLength);
 	}
@@ -114,7 +113,7 @@ void WP3WindowGroup::parse(WP3Listener *listener)
 	case WP3_WINDOW_GROUP_HTML_IMAGE_BOX_FUNCTION:
 		if (m_boxType == 0x02)
 		{
-			WPXBinaryData tmpWBOXData;
+			librevenge::RVNGBinaryData tmpWBOXData;
 			for (int i=0; i < 512; i++)
 				tmpWBOXData.append((unsigned char)0);
 			if (listener->getResourceFork() && listener->getResourceFork()->getResource(0x57424f58, m_resourceID)) // WBOX resource
@@ -125,7 +124,7 @@ void WP3WindowGroup::parse(WP3Listener *listener)
 		}
 		else if (m_boxType == 0x01 || m_boxType == 0x03)
 		{
-			WPXBinaryData tmpPICTData;
+			librevenge::RVNGBinaryData tmpPICTData;
 			for (int i=0; i < 512; i++)
 				tmpPICTData.append((unsigned char)0);
 			if (listener->getResourceFork() && listener->getResourceFork()->getResource(0x50494354, m_resourceID)) // replacement picture in PICT format
