@@ -1,20 +1,21 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: t; c-basic-offset: 4 -*- */
 /* libwpd
+ * Version: MPL 2.0 / LGPLv2.1+
+ *
+ * This Source Code Form is subject to the terms of the Mozilla Public
+ * License, v. 2.0. If a copy of the MPL was not distributed with this
+ * file, You can obtain one at http://mozilla.org/MPL/2.0/.
+ *
+ * Major Contributor(s):
  * Copyright (C) 2003 William Lachance (wrlach@gmail.com)
  * Copyright (C) 2003-2004 Marc Maurer (uwog@uwog.net)
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public
- * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
+ * For minor contributions see the git repository.
  *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
- *
- * You should have received a copy of the GNU Library General Public
- * License along with this library; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
+ * Alternatively, the contents of this file may be used under the terms
+ * of the GNU Lesser General Public License Version 2.1 or later
+ * (LGPLv2.1+), in which case the provisions of the LGPLv2.1+ are
+ * applicable instead of those above.
  *
  * For further information visit http://libwpd.sourceforge.net
  */
@@ -23,7 +24,7 @@
  * Corel Corporation or Corel Corporation Limited."
  */
 
-#include "WPDocument.h"
+#include <librevenge/librevenge.h>
 #include "WPXHeader.h"
 #include "WPXParser.h"
 #include "WP1Parser.h"
@@ -33,17 +34,18 @@
 #include "WP42Heuristics.h"
 #include "WP5Parser.h"
 #include "WP6Parser.h"
-#include "WPXStream.h"
 #include "WPXEncryption.h"
 #include "libwpd_internal.h"
 
+using namespace libwpd;
+
 /**
 \mainpage libwpd documentation
 This document contains both the libwpd API specification and the normal libwpd
 documentation.
 \section api_docs libwpd API documentation
 The external libwpd API is provided by the WPDocument class. This class, combined
-with the WPXDocumentInterface class, are the only two classes that will be of interest
+with the librevenge::RVNGTextInterface class, are the only two classes that will be of interest
 for the application programmer using libwpd.
 \section lib_docs libwpd documentation
 If you are interrested in the structure of libwpd itself, this whole document
@@ -58,20 +60,20 @@ Analyzes the content of an input stream to see if it can be parsed
 \return A confidence value which represents the likelyhood that the content from
 the input stream can be parsed
 */
-WPDConfidence WPDocument::isFileFormatSupported(WPXInputStream *input)
+WPDAPI WPDConfidence WPDocument::isFileFormatSupported(librevenge::RVNGInputStream *input)
 {
 	WPD_DEBUG_MSG(("WPDocument::isFileFormatSupported()\n"));
 
 	// by-pass the OLE stream (if it exists) and returns the (sub) stream with the
 	// WordPerfect document.
-	WPXInputStream *document = 0;
-	bool isDocumentOLE = false;
+	librevenge::RVNGInputStream *document = 0;
+	bool isStructuredDocument = false;
 
-	if (input->isOLEStream())
+	if (input->isStructured())
 	{
-		document = input->getDocumentOLEStream("PerfectOffice_MAIN");
+		document = input->getSubStreamByName("PerfectOffice_MAIN");
 		if (document)
-			isDocumentOLE = true;
+			isStructuredDocument = true;
 		else
 			return WPD_CONFIDENCE_NONE;
 	}
@@ -86,37 +88,37 @@ WPDConfidence WPDocument::isFileFormatSupported(WPXInputStream *input)
 		{
 			switch (header->getFileType())
 			{
-				case 0x0a: // WordPerfect File
-					switch (header->getMajorVersion())
-					{
-						case 0x00: // WP5
-						case 0x02: // WP6+
-							confidence = WPD_CONFIDENCE_EXCELLENT;
-							break;
-						default:
-							// unhandled file format
-							confidence = WPD_CONFIDENCE_NONE;
-							break;
-					}
-					break;
-				case 0x2c: // WP Mac File
-					switch (header->getMajorVersion())
-					{
-						case 0x02: // WP Mac 2.x
-						case 0x03: // WP Mac 3.0-3.5
-						case 0x04: // WP Mac 3.5e
-							confidence = WPD_CONFIDENCE_EXCELLENT;
-							break;
-						default:
-							// unhandled file format
-							confidence = WPD_CONFIDENCE_NONE;
-							break;
-					}
+			case 0x0a: // WordPerfect File
+				switch (header->getMajorVersion())
+				{
+				case 0x00: // WP5
+				case 0x02: // WP6+
+					confidence = WPD_CONFIDENCE_EXCELLENT;
 					break;
 				default:
-					// unhandled file type
+					// unhandled file format
 					confidence = WPD_CONFIDENCE_NONE;
 					break;
+				}
+				break;
+			case 0x2c: // WP Mac File
+				switch (header->getMajorVersion())
+				{
+				case 0x02: // WP Mac 2.x
+				case 0x03: // WP Mac 3.0-3.5
+				case 0x04: // WP Mac 3.5e
+					confidence = WPD_CONFIDENCE_EXCELLENT;
+					break;
+				default:
+					// unhandled file format
+					confidence = WPD_CONFIDENCE_NONE;
+					break;
+				}
+				break;
+			default:
+				// unhandled file type
+				confidence = WPD_CONFIDENCE_NONE;
+				break;
 			}
 			if (header->getDocumentEncryption())
 			{
@@ -129,12 +131,12 @@ WPDConfidence WPDocument::isFileFormatSupported(WPXInputStream *input)
 		}
 		else
 			confidence = WP1Heuristics::isWP1FileFormat(input, 0);
-			if (confidence != WPD_CONFIDENCE_EXCELLENT && confidence != WPD_CONFIDENCE_SUPPORTED_ENCRYPTION)
-				confidence = LIBWPD_MAX(confidence, WP42Heuristics::isWP42FileFormat(input, 0));
-			
+		if (confidence != WPD_CONFIDENCE_EXCELLENT && confidence != WPD_CONFIDENCE_SUPPORTED_ENCRYPTION)
+			confidence = LIBWPD_MAX(confidence, WP42Heuristics::isWP42FileFormat(input, 0));
+
 
 		// dispose of the reference to the ole input stream, if we allocated one
-		if (document && isDocumentOLE)
+		if (document && isStructuredDocument)
 			DELETEP(document);
 
 		return confidence;
@@ -144,7 +146,7 @@ WPDConfidence WPDocument::isFileFormatSupported(WPXInputStream *input)
 		WPD_DEBUG_MSG(("File Exception trapped\n"));
 
 		// dispose of the reference to the ole input stream, if we allocated one
-		if (document && isDocumentOLE)
+		if (document && isStructuredDocument)
 			DELETEP(document);
 
 		return WPD_CONFIDENCE_NONE;
@@ -154,7 +156,7 @@ WPDConfidence WPDocument::isFileFormatSupported(WPXInputStream *input)
 		WPD_DEBUG_MSG(("Unknown Exception trapped\n"));
 
 		// dispose of the reference to the ole input stream, if we allocated one
-		if (document && isDocumentOLE)
+		if (document && isStructuredDocument)
 			DELETEP(document);
 
 		return WPD_CONFIDENCE_NONE;
@@ -167,14 +169,14 @@ Checks whether the given password was used to encrypt the document
 \param password The password used to protect the document or NULL if the document is not protected
 \return A value which indicates between the given password and the password that was used to protect the document
 */
-WPDPasswordMatch WPDocument::verifyPassword(WPXInputStream *input, const char *password)
+WPDAPI WPDPasswordMatch WPDocument::verifyPassword(librevenge::RVNGInputStream *input, const char *password)
 {
 	if (!password)
 		return WPD_PASSWORD_MATCH_DONTKNOW;
 	if (!input)
 		return WPD_PASSWORD_MATCH_DONTKNOW;
 
-	input->seek(0, WPX_SEEK_SET);
+	input->seek(0, librevenge::RVNG_SEEK_SET);
 
 	WPDPasswordMatch passwordMatch = WPD_PASSWORD_MATCH_NONE;
 	WPXEncryption encryption(password);
@@ -185,14 +187,14 @@ WPDPasswordMatch WPDocument::verifyPassword(WPXInputStream *input, const char *p
 
 	// by-pass the OLE stream (if it exists) and returns the (sub) stream with the
 	// WordPerfect document.
-	WPXInputStream *document = 0;
-	bool isDocumentOLE = false;
+	librevenge::RVNGInputStream *document = 0;
+	bool isStructuredDocument = false;
 
-	if (input->isOLEStream())
+	if (input->isStructured())
 	{
-		document = input->getDocumentOLEStream("PerfectOffice_MAIN");
+		document = input->getSubStreamByName("PerfectOffice_MAIN");
 		if (document)
-			isDocumentOLE = true;
+			isStructuredDocument = true;
 		else
 			return WPD_PASSWORD_MATCH_NONE;
 	}
@@ -215,12 +217,12 @@ WPDPasswordMatch WPDocument::verifyPassword(WPXInputStream *input, const char *p
 		}
 		else
 			passwordMatch = WP1Heuristics::verifyPassword(input, password);
-			if (passwordMatch == WPD_PASSWORD_MATCH_NONE)
-				passwordMatch = LIBWPD_MAX(passwordMatch, WP42Heuristics::verifyPassword(input, password));
-			
+		if (passwordMatch == WPD_PASSWORD_MATCH_NONE)
+			passwordMatch = LIBWPD_MAX(passwordMatch, WP42Heuristics::verifyPassword(input, password));
+
 
 		// dispose of the reference to the ole input stream, if we allocated one
-		if (document && isDocumentOLE)
+		if (document && isStructuredDocument)
 			DELETEP(document);
 
 		return passwordMatch;
@@ -230,7 +232,7 @@ WPDPasswordMatch WPDocument::verifyPassword(WPXInputStream *input, const char *p
 		WPD_DEBUG_MSG(("File Exception trapped\n"));
 
 		// dispose of the reference to the ole input stream, if we allocated one
-		if (document && isDocumentOLE)
+		if (document && isStructuredDocument)
 			DELETEP(document);
 
 		return WPD_PASSWORD_MATCH_NONE;
@@ -240,7 +242,7 @@ WPDPasswordMatch WPDocument::verifyPassword(WPXInputStream *input, const char *p
 		WPD_DEBUG_MSG(("Unknown Exception trapped\n"));
 
 		// dispose of the reference to the ole input stream, if we allocated one
-		if (document && isDocumentOLE)
+		if (document && isStructuredDocument)
 			DELETEP(document);
 
 		return WPD_PASSWORD_MATCH_NONE;
@@ -249,40 +251,39 @@ WPDPasswordMatch WPDocument::verifyPassword(WPXInputStream *input, const char *p
 
 /**
 Parses the input stream content. It will make callbacks to the functions provided by a
-WPXDocumentInterface class implementation when needed. This is often commonly called the
+librevenge::RVNGTextInterface class implementation when needed. This is often commonly called the
 'main parsing routine'.
 \param input The input stream
-\param documentInterface A WPXDocumentInterface implementation
+\param textInterface A librevenge::RVNGTextInterface implementation
 \param password The password used to protect the document or NULL if the document
 is not protected
 \return A value that indicates whether the conversion was successful and in case it
 was not, it indicates the reason of the error
 */
-WPDResult WPDocument::parse(WPXInputStream *input, WPXDocumentInterface *documentInterface, const char *password)
+WPDAPI WPDResult WPDocument::parse(librevenge::RVNGInputStream *input, librevenge::RVNGTextInterface *textInterface, const char *password)
 {
 	if (!input)
 		return WPD_FILE_ACCESS_ERROR;
-		
+
 	if (password && verifyPassword(input, password) != WPD_PASSWORD_MATCH_OK)
 		return WPD_PASSWORD_MISSMATCH_ERROR;
-		
-	input->seek(0, WPX_SEEK_SET);
+
+	input->seek(0, librevenge::RVNG_SEEK_SET);
 
 	WPXParser *parser = 0;
-	WPXEncryption *encryption = (password) ? new WPXEncryption(password) : 0;
 
 	// by-pass the OLE stream (if it exists) and returns the (sub) stream with the
 	// WordPerfect document.
 
-	WPXInputStream *document = 0;
-	bool isDocumentOLE = false;
+	librevenge::RVNGInputStream *document = 0;
+	bool isStructuredDocument = false;
 
 	WPD_DEBUG_MSG(("WPDocument::parse()\n"));
-	if (input->isOLEStream())
+	if (input->isStructured())
 	{
-		document = input->getDocumentOLEStream("PerfectOffice_MAIN");
+		document = input->getSubStreamByName("PerfectOffice_MAIN");
 		if (document)
-			isDocumentOLE = true;
+			isStructuredDocument = true;
 		else
 			return WPD_OLE_ERROR;
 	}
@@ -293,67 +294,61 @@ WPDResult WPDocument::parse(WPXInputStream *input, WPXDocumentInterface *documen
 
 	try
 	{
+		WPXEncryption *encryption = 0;
 		WPXHeader *header = WPXHeader::constructHeader(document, 0);
 
 		if (header)
 		{
 			switch (header->getFileType())
 			{
-				case 0x0a: // WordPerfect File
-					switch (header->getMajorVersion())
-					{
-						case 0x00: // WP5
-							WPD_DEBUG_MSG(("WordPerfect: Using the WP5 parser.\n"));
-							if (encryption)
-							{
-								delete encryption;
-								encryption = new WPXEncryption(password, 16);
-							}
-							parser = new WP5Parser(document, header, encryption);
-							parser->parse(documentInterface);
-							break;
-						case 0x02: // WP6
-							WPD_DEBUG_MSG(("WordPerfect: Using the WP6 parser.\n"));
-							if (encryption)
-						 	{
-								delete encryption;
-								encryption = 0;
-								throw UnsupportedEncryptionException();
-							}
-							parser = new WP6Parser(document, header, encryption);
-							parser->parse(documentInterface);
-							break;
-						default:
-							// unhandled file format
-							WPD_DEBUG_MSG(("WordPerfect: Unsupported file format.\n"));
-							break;
-					}
+			case 0x0a: // WordPerfect File
+				switch (header->getMajorVersion())
+				{
+				case 0x00: // WP5
+					WPD_DEBUG_MSG(("WordPerfect: Using the WP5 parser.\n"));
+					if (password)
+						encryption = new WPXEncryption(password, 16);
+					parser = new WP5Parser(document, header, encryption);
+					parser->parse(textInterface);
 					break;
-				case 0x2c: // WP Mac File
-					switch (header->getMajorVersion())
+				case 0x02: // WP6
+					WPD_DEBUG_MSG(("WordPerfect: Using the WP6 parser.\n"));
+					if (password)
 					{
-						case 0x02: // WP Mac 2.x
-						case 0x03: // WP Mac 3.0-3.5
-						case 0x04: // WP Mac 3.5e
-							WPD_DEBUG_MSG(("WordPerfect: Using the WP3 parser.\n"));
-							if (encryption)
-							{
-								delete encryption;
-								encryption = new WPXEncryption(password, header->getDocumentOffset());
-							}
-							parser = new WP3Parser(document, header, encryption);
-							parser->parse(documentInterface);
-							break;
-						default:
-							// unhandled file format
-							WPD_DEBUG_MSG(("WordPerfect: Unsupported file format.\n"));
-							break;
+						delete header;
+						throw UnsupportedEncryptionException();
 					}
+					parser = new WP6Parser(document, header, encryption);
+					parser->parse(textInterface);
 					break;
 				default:
 					// unhandled file format
-					WPD_DEBUG_MSG(("WordPerfect: Unsupported file type.\n"));
+					WPD_DEBUG_MSG(("WordPerfect: Unsupported file format.\n"));
 					break;
+				}
+				break;
+			case 0x2c: // WP Mac File
+				switch (header->getMajorVersion())
+				{
+				case 0x02: // WP Mac 2.x
+				case 0x03: // WP Mac 3.0-3.5
+				case 0x04: // WP Mac 3.5e
+					WPD_DEBUG_MSG(("WordPerfect: Using the WP3 parser.\n"));
+					if (password)
+						encryption = new WPXEncryption(password, header->getDocumentOffset());
+					parser = new WP3Parser(document, header, encryption);
+					parser->parse(textInterface);
+					break;
+				default:
+					// unhandled file format
+					WPD_DEBUG_MSG(("WordPerfect: Unsupported file format.\n"));
+					break;
+				}
+				break;
+			default:
+				// unhandled file format
+				WPD_DEBUG_MSG(("WordPerfect: Unsupported file type.\n"));
+				break;
 			}
 			DELETEP(parser);
 			DELETEP(header);
@@ -368,27 +363,23 @@ WPDResult WPDocument::parse(WPXInputStream *input, WPXDocumentInterface *documen
 			{
 				WPD_DEBUG_MSG(("WordPerfect: Mostly likely the file format is WP Mac 1.x.\n\n"));
 				WPD_DEBUG_MSG(("WordPerfect: Using the WP Mac 1.x parser.\n\n"));
-				if (encryption)
-				{
-					delete encryption;
+				if (password)
 					encryption = new WPXEncryption(password, 6);
-				}
 				parser = new WP1Parser(document, encryption);
-				parser->parse(documentInterface);
+				parser->parse(textInterface);
 				DELETEP(parser);
 			}
 			else if (WP42Heuristics::isWP42FileFormat(document, password) == WPD_CONFIDENCE_EXCELLENT)
 			{
 				WPD_DEBUG_MSG(("WordPerfect: Mostly likely the file format is WP4.2.\n\n"));
 				WPD_DEBUG_MSG(("WordPerfect: Using the WP4.2 parser.\n\n"));
-				if (encryption)
+				if (password)
 				{
-					delete encryption;
 					encryption = new WPXEncryption(password, 6);
-					input->seek(6, WPX_SEEK_SET);
+					input->seek(6, librevenge::RVNG_SEEK_SET);
 				}
 				parser = new WP42Parser(document, encryption);
-				parser->parse(documentInterface);
+				parser->parse(textInterface);
 				DELETEP(parser);
 			}
 			else
@@ -415,25 +406,25 @@ WPDResult WPDocument::parse(WPXInputStream *input, WPXDocumentInterface *documen
 	catch (...)
 	{
 		WPD_DEBUG_MSG(("Unknown Exception trapped\n"));
-		error = WPD_UNKNOWN_ERROR; 
+		error = WPD_UNKNOWN_ERROR;
 	}
 
 	DELETEP(parser);
-	if (document && isDocumentOLE)
+	if (document && isStructuredDocument)
 		DELETEP(document);
 
 	return error;
 }
 
-WPDResult WPDocument::parseSubDocument(WPXInputStream *input, WPXDocumentInterface *documentInterface, WPDFileFormat fileFormat)
+WPDAPI WPDResult WPDocument::parseSubDocument(librevenge::RVNGInputStream *input, librevenge::RVNGTextInterface *textInterface, WPDFileFormat fileFormat)
 {
 	WPXParser *parser = 0;
-	
+
 	WPDResult error = WPD_OK;
 
 	try
 	{
-		
+
 		switch (fileFormat)
 		{
 		case WPD_FILE_FORMAT_WP6:
@@ -456,9 +447,9 @@ WPDResult WPDocument::parseSubDocument(WPXInputStream *input, WPXDocumentInterfa
 			DELETEP(parser);
 			return WPD_UNKNOWN_ERROR;
 		}
-		
+
 		if (parser)
-			parser->parseSubDocument(documentInterface);
+			parser->parseSubDocument(textInterface);
 	}
 	catch (FileException)
 	{
@@ -478,8 +469,9 @@ WPDResult WPDocument::parseSubDocument(WPXInputStream *input, WPXDocumentInterfa
 	catch (...)
 	{
 		WPD_DEBUG_MSG(("Unknown Exception trapped\n"));
-		error = WPD_UNKNOWN_ERROR; 
+		error = WPD_UNKNOWN_ERROR;
 	}
 	DELETEP(parser);
 	return error;
 }
+/* vim:set shiftwidth=4 softtabstop=4 noexpandtab: */
